@@ -2,7 +2,7 @@
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
 # Conversion routines for IBM891.
-# Copyright (C) 2002-2015 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2002-2026 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software: you can redistribute it and/or modify
@@ -860,8 +860,9 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
 
 =head1 AUTHOR
 
-Copyright (C) 2002-2015, Guido Flohr E<lt>guido.flohr@cantanea.comE<gt>, all
-rights reserved.  See the source code for details.
+Copyright (C) 2002-2026 L<Guido Flohr|http://www.guido-flohr.net/>
+(L<mailto:guido.flohr@cantanea.com>), all rights reserved.  See the source
+code for details!code for details!
 
 =head1 SEE ALSO
 
@@ -880,4 +881,3 @@ cperl-indent-level: 4
 cperl-continued-statement-offset: 2
 tab-width: 4
 End:
-=cut
