@@ -1,8 +1,8 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-9.
-# Copyright (C) 2002-2017 Guido Flohr <guido.flohr@cantanea.com>,
+# Conversion routines for ISO-8859-3.
+# Copyright (C) 2002-2026 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_9;
+package Locale::RecodeData::ISO_8859_3;
 
 use strict;
 
@@ -187,44 +187,44 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0x00a1,
-    0x00a2,
+    0x0126,
+    0x02d8,
     0x00a3,
     0x00a4,
-    0x00a5,
-    0x00a6,
+    0xfffd,
+    0x0124,
     0x00a7,
     0x00a8,
-    0x00a9,
-    0x00aa,
-    0x00ab,
-    0x00ac,
+    0x0130,
+    0x015e,
+    0x011e,
+    0x0134,
     0x00ad,
-    0x00ae,
-    0x00af,
+    0xfffd,
+    0x017b,
     0x00b0,
-    0x00b1,
+    0x0127,
     0x00b2,
     0x00b3,
     0x00b4,
     0x00b5,
-    0x00b6,
+    0x0125,
     0x00b7,
     0x00b8,
-    0x00b9,
-    0x00ba,
-    0x00bb,
-    0x00bc,
+    0x0131,
+    0x015f,
+    0x011f,
+    0x0135,
     0x00bd,
-    0x00be,
-    0x00bf,
+    0xfffd,
+    0x017c,
     0x00c0,
     0x00c1,
     0x00c2,
-    0x00c3,
+    0xfffd,
     0x00c4,
-    0x00c5,
-    0x00c6,
+    0x010a,
+    0x0108,
     0x00c7,
     0x00c8,
     0x00c9,
@@ -234,29 +234,29 @@ my @to_ucs4 = (
     0x00cd,
     0x00ce,
     0x00cf,
-    0x011e,
+    0xfffd,
     0x00d1,
     0x00d2,
     0x00d3,
     0x00d4,
-    0x00d5,
+    0x0120,
     0x00d6,
     0x00d7,
-    0x00d8,
+    0x011c,
     0x00d9,
     0x00da,
     0x00db,
     0x00dc,
-    0x0130,
-    0x015e,
+    0x016c,
+    0x015c,
     0x00df,
     0x00e0,
     0x00e1,
     0x00e2,
-    0x00e3,
+    0xfffd,
     0x00e4,
-    0x00e5,
-    0x00e6,
+    0x010b,
+    0x0109,
     0x00e7,
     0x00e8,
     0x00e9,
@@ -266,22 +266,22 @@ my @to_ucs4 = (
     0x00ed,
     0x00ee,
     0x00ef,
-    0x011f,
+    0xfffd,
     0x00f1,
     0x00f2,
     0x00f3,
     0x00f4,
-    0x00f5,
+    0x0121,
     0x00f6,
     0x00f7,
-    0x00f8,
+    0x011d,
     0x00f9,
     0x00fa,
     0x00fb,
     0x00fc,
-    0x0131,
-    0x015f,
-    0x00ff,
+    0x016d,
+    0x015d,
+    0x02d9,
 );
 
 my @to_utf8 = (
@@ -446,44 +446,44 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xc2\xa1",
-    "\xc2\xa2",
+    "\xc4\xa6",
+    "\xcb\x98",
     "\xc2\xa3",
     "\xc2\xa4",
-    "\xc2\xa5",
-    "\xc2\xa6",
+    "\xef\xbf\xbd",
+    "\xc4\xa4",
     "\xc2\xa7",
     "\xc2\xa8",
-    "\xc2\xa9",
-    "\xc2\xaa",
-    "\xc2\xab",
-    "\xc2\xac",
+    "\xc4\xb0",
+    "\xc5\x9e",
+    "\xc4\x9e",
+    "\xc4\xb4",
     "\xc2\xad",
-    "\xc2\xae",
-    "\xc2\xaf",
+    "\xef\xbf\xbd",
+    "\xc5\xbb",
     "\xc2\xb0",
-    "\xc2\xb1",
+    "\xc4\xa7",
     "\xc2\xb2",
     "\xc2\xb3",
     "\xc2\xb4",
     "\xc2\xb5",
-    "\xc2\xb6",
+    "\xc4\xa5",
     "\xc2\xb7",
     "\xc2\xb8",
-    "\xc2\xb9",
-    "\xc2\xba",
-    "\xc2\xbb",
-    "\xc2\xbc",
+    "\xc4\xb1",
+    "\xc5\x9f",
+    "\xc4\x9f",
+    "\xc4\xb5",
     "\xc2\xbd",
-    "\xc2\xbe",
-    "\xc2\xbf",
+    "\xef\xbf\xbd",
+    "\xc5\xbc",
     "\xc3\x80",
     "\xc3\x81",
     "\xc3\x82",
-    "\xc3\x83",
+    "\xef\xbf\xbd",
     "\xc3\x84",
-    "\xc3\x85",
-    "\xc3\x86",
+    "\xc4\x8a",
+    "\xc4\x88",
     "\xc3\x87",
     "\xc3\x88",
     "\xc3\x89",
@@ -493,29 +493,29 @@ my @to_utf8 = (
     "\xc3\x8d",
     "\xc3\x8e",
     "\xc3\x8f",
-    "\xc4\x9e",
+    "\xef\xbf\xbd",
     "\xc3\x91",
     "\xc3\x92",
     "\xc3\x93",
     "\xc3\x94",
-    "\xc3\x95",
+    "\xc4\xa0",
     "\xc3\x96",
     "\xc3\x97",
-    "\xc3\x98",
+    "\xc4\x9c",
     "\xc3\x99",
     "\xc3\x9a",
     "\xc3\x9b",
     "\xc3\x9c",
-    "\xc4\xb0",
-    "\xc5\x9e",
+    "\xc5\xac",
+    "\xc5\x9c",
     "\xc3\x9f",
     "\xc3\xa0",
     "\xc3\xa1",
     "\xc3\xa2",
-    "\xc3\xa3",
+    "\xef\xbf\xbd",
     "\xc3\xa4",
-    "\xc3\xa5",
-    "\xc3\xa6",
+    "\xc4\x8b",
+    "\xc4\x89",
     "\xc3\xa7",
     "\xc3\xa8",
     "\xc3\xa9",
@@ -525,22 +525,22 @@ my @to_utf8 = (
     "\xc3\xad",
     "\xc3\xae",
     "\xc3\xaf",
-    "\xc4\x9f",
+    "\xef\xbf\xbd",
     "\xc3\xb1",
     "\xc3\xb2",
     "\xc3\xb3",
     "\xc3\xb4",
-    "\xc3\xb5",
+    "\xc4\xa1",
     "\xc3\xb6",
     "\xc3\xb7",
-    "\xc3\xb8",
+    "\xc4\x9d",
     "\xc3\xb9",
     "\xc3\xba",
     "\xc3\xbb",
     "\xc3\xbc",
-    "\xc4\xb1",
-    "\xc5\x9f",
-    "\xc3\xbf",
+    "\xc5\xad",
+    "\xc5\x9d",
+    "\xcb\x99",
 );
 
 my %from_ucs4 = (
@@ -705,44 +705,23 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
-    0x000000a1 => "\xa1",
-    0x000000a2 => "\xa2",
     0x000000a3 => "\xa3",
     0x000000a4 => "\xa4",
-    0x000000a5 => "\xa5",
-    0x000000a6 => "\xa6",
     0x000000a7 => "\xa7",
     0x000000a8 => "\xa8",
-    0x000000a9 => "\xa9",
-    0x000000aa => "\xaa",
-    0x000000ab => "\xab",
-    0x000000ac => "\xac",
     0x000000ad => "\xad",
-    0x000000ae => "\xae",
-    0x000000af => "\xaf",
     0x000000b0 => "\xb0",
-    0x000000b1 => "\xb1",
     0x000000b2 => "\xb2",
     0x000000b3 => "\xb3",
     0x000000b4 => "\xb4",
     0x000000b5 => "\xb5",
-    0x000000b6 => "\xb6",
     0x000000b7 => "\xb7",
     0x000000b8 => "\xb8",
-    0x000000b9 => "\xb9",
-    0x000000ba => "\xba",
-    0x000000bb => "\xbb",
-    0x000000bc => "\xbc",
     0x000000bd => "\xbd",
-    0x000000be => "\xbe",
-    0x000000bf => "\xbf",
     0x000000c0 => "\xc0",
     0x000000c1 => "\xc1",
     0x000000c2 => "\xc2",
-    0x000000c3 => "\xc3",
     0x000000c4 => "\xc4",
-    0x000000c5 => "\xc5",
-    0x000000c6 => "\xc6",
     0x000000c7 => "\xc7",
     0x000000c8 => "\xc8",
     0x000000c9 => "\xc9",
@@ -756,10 +735,8 @@ my %from_ucs4 = (
     0x000000d2 => "\xd2",
     0x000000d3 => "\xd3",
     0x000000d4 => "\xd4",
-    0x000000d5 => "\xd5",
     0x000000d6 => "\xd6",
     0x000000d7 => "\xd7",
-    0x000000d8 => "\xd8",
     0x000000d9 => "\xd9",
     0x000000da => "\xda",
     0x000000db => "\xdb",
@@ -768,10 +745,7 @@ my %from_ucs4 = (
     0x000000e0 => "\xe0",
     0x000000e1 => "\xe1",
     0x000000e2 => "\xe2",
-    0x000000e3 => "\xe3",
     0x000000e4 => "\xe4",
-    0x000000e5 => "\xe5",
-    0x000000e6 => "\xe6",
     0x000000e7 => "\xe7",
     0x000000e8 => "\xe8",
     0x000000e9 => "\xe9",
@@ -785,21 +759,40 @@ my %from_ucs4 = (
     0x000000f2 => "\xf2",
     0x000000f3 => "\xf3",
     0x000000f4 => "\xf4",
-    0x000000f5 => "\xf5",
     0x000000f6 => "\xf6",
     0x000000f7 => "\xf7",
-    0x000000f8 => "\xf8",
     0x000000f9 => "\xf9",
     0x000000fa => "\xfa",
     0x000000fb => "\xfb",
     0x000000fc => "\xfc",
-    0x000000ff => "\xff",
-    0x0000011e => "\xd0",
-    0x0000011f => "\xf0",
-    0x00000130 => "\xdd",
-    0x00000131 => "\xfd",
-    0x0000015e => "\xde",
-    0x0000015f => "\xfe",
+    0x00000108 => "\xc6",
+    0x00000109 => "\xe6",
+    0x0000010a => "\xc5",
+    0x0000010b => "\xe5",
+    0x0000011c => "\xd8",
+    0x0000011d => "\xf8",
+    0x0000011e => "\xab",
+    0x0000011f => "\xbb",
+    0x00000120 => "\xd5",
+    0x00000121 => "\xf5",
+    0x00000124 => "\xa6",
+    0x00000125 => "\xb6",
+    0x00000126 => "\xa1",
+    0x00000127 => "\xb1",
+    0x00000130 => "\xa9",
+    0x00000131 => "\xb9",
+    0x00000134 => "\xac",
+    0x00000135 => "\xbc",
+    0x0000015c => "\xde",
+    0x0000015d => "\xfe",
+    0x0000015e => "\xaa",
+    0x0000015f => "\xba",
+    0x0000016c => "\xdd",
+    0x0000016d => "\xfd",
+    0x0000017b => "\xaf",
+    0x0000017c => "\xbf",
+    0x000002d8 => "\xa2",
+    0x000002d9 => "\xff",
 );
 
 sub _recode
@@ -827,7 +820,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_9 - Conversion routines for ISO-8859-9
+Locale::RecodeData::ISO_8859_3 - Conversion routines for ISO-8859-3
 
 =head1 SYNOPSIS
 
@@ -836,7 +829,7 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-9.
+routines for ISO-8859-3.
 
 =head1 COMMENTS
 
@@ -844,11 +837,11 @@ The following comments have been extracted from the original charmap:
 
  version: 1.0
   source: ECMA registry
- alias ISO-IR-148
- alias ISO_8859-9:1989
- alias ISO_8859-9
- alias LATIN5
- alias L5
+ alias ISO-IR-109
+ alias ISO_8859-3:1988
+ alias ISO_8859-3
+ alias LATIN3
+ alias L3
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -1021,44 +1014,40 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A1 |  000000A1 | INVERTED EXCLAMATION MARK
-    A2 |  000000A2 | CENT SIGN
+    A1 |  00000126 | LATIN CAPITAL LETTER H WITH STROKE
+    A2 |  000002D8 | BREVE
     A3 |  000000A3 | POUND SIGN
     A4 |  000000A4 | CURRENCY SIGN
-    A5 |  000000A5 | YEN SIGN
-    A6 |  000000A6 | BROKEN BAR
+    A6 |  00000124 | LATIN CAPITAL LETTER H WITH CIRCUMFLEX
     A7 |  000000A7 | SECTION SIGN
     A8 |  000000A8 | DIAERESIS
-    A9 |  000000A9 | COPYRIGHT SIGN
-    AA |  000000AA | FEMININE ORDINAL INDICATOR
-    AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
-    AC |  000000AC | NOT SIGN
+    A9 |  00000130 | LATIN CAPITAL LETTER I WITH DOT ABOVE
+    AA |  0000015E | LATIN CAPITAL LETTER S WITH CEDILLA
+    AB |  0000011E | LATIN CAPITAL LETTER G WITH BREVE
+    AC |  00000134 | LATIN CAPITAL LETTER J WITH CIRCUMFLEX
     AD |  000000AD | SOFT HYPHEN
-    AE |  000000AE | REGISTERED SIGN
-    AF |  000000AF | MACRON
+    AF |  0000017B | LATIN CAPITAL LETTER Z WITH DOT ABOVE
     B0 |  000000B0 | DEGREE SIGN
-    B1 |  000000B1 | PLUS-MINUS SIGN
+    B1 |  00000127 | LATIN SMALL LETTER H WITH STROKE
     B2 |  000000B2 | SUPERSCRIPT TWO
     B3 |  000000B3 | SUPERSCRIPT THREE
     B4 |  000000B4 | ACUTE ACCENT
     B5 |  000000B5 | MICRO SIGN
-    B6 |  000000B6 | PILCROW SIGN
+    B6 |  00000125 | LATIN SMALL LETTER H WITH CIRCUMFLEX
     B7 |  000000B7 | MIDDLE DOT
     B8 |  000000B8 | CEDILLA
-    B9 |  000000B9 | SUPERSCRIPT ONE
-    BA |  000000BA | MASCULINE ORDINAL INDICATOR
-    BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
-    BC |  000000BC | VULGAR FRACTION ONE QUARTER
+    B9 |  00000131 | LATIN SMALL LETTER DOTLESS I
+    BA |  0000015F | LATIN SMALL LETTER S WITH CEDILLA
+    BB |  0000011F | LATIN SMALL LETTER G WITH BREVE
+    BC |  00000135 | LATIN SMALL LETTER J WITH CIRCUMFLEX
     BD |  000000BD | VULGAR FRACTION ONE HALF
-    BE |  000000BE | VULGAR FRACTION THREE QUARTERS
-    BF |  000000BF | INVERTED QUESTION MARK
+    BF |  0000017C | LATIN SMALL LETTER Z WITH DOT ABOVE
     C0 |  000000C0 | LATIN CAPITAL LETTER A WITH GRAVE
     C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
     C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
-    C3 |  000000C3 | LATIN CAPITAL LETTER A WITH TILDE
     C4 |  000000C4 | LATIN CAPITAL LETTER A WITH DIAERESIS
-    C5 |  000000C5 | LATIN CAPITAL LETTER A WITH RING ABOVE
-    C6 |  000000C6 | LATIN CAPITAL LETTER AE
+    C5 |  0000010A | LATIN CAPITAL LETTER C WITH DOT ABOVE
+    C6 |  00000108 | LATIN CAPITAL LETTER C WITH CIRCUMFLEX
     C7 |  000000C7 | LATIN CAPITAL LETTER C WITH CEDILLA
     C8 |  000000C8 | LATIN CAPITAL LETTER E WITH GRAVE
     C9 |  000000C9 | LATIN CAPITAL LETTER E WITH ACUTE
@@ -1068,29 +1057,27 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
     CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
     CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
-    D0 |  0000011E | LATIN CAPITAL LETTER G WITH BREVE
     D1 |  000000D1 | LATIN CAPITAL LETTER N WITH TILDE
     D2 |  000000D2 | LATIN CAPITAL LETTER O WITH GRAVE
     D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
     D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
-    D5 |  000000D5 | LATIN CAPITAL LETTER O WITH TILDE
+    D5 |  00000120 | LATIN CAPITAL LETTER G WITH DOT ABOVE
     D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
     D7 |  000000D7 | MULTIPLICATION SIGN
-    D8 |  000000D8 | LATIN CAPITAL LETTER O WITH STROKE
+    D8 |  0000011C | LATIN CAPITAL LETTER G WITH CIRCUMFLEX
     D9 |  000000D9 | LATIN CAPITAL LETTER U WITH GRAVE
     DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
     DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
     DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
-    DD |  00000130 | LATIN CAPITAL LETTER I WITH DOT ABOVE
-    DE |  0000015E | LATIN CAPITAL LETTER S WITH CEDILLA
+    DD |  0000016C | LATIN CAPITAL LETTER U WITH BREVE
+    DE |  0000015C | LATIN CAPITAL LETTER S WITH CIRCUMFLEX
     DF |  000000DF | LATIN SMALL LETTER SHARP S (German)
     E0 |  000000E0 | LATIN SMALL LETTER A WITH GRAVE
     E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
     E2 |  000000E2 | LATIN SMALL LETTER A WITH CIRCUMFLEX
-    E3 |  000000E3 | LATIN SMALL LETTER A WITH TILDE
     E4 |  000000E4 | LATIN SMALL LETTER A WITH DIAERESIS
-    E5 |  000000E5 | LATIN SMALL LETTER A WITH RING ABOVE
-    E6 |  000000E6 | LATIN SMALL LETTER AE
+    E5 |  0000010B | LATIN SMALL LETTER C WITH DOT ABOVE
+    E6 |  00000109 | LATIN SMALL LETTER C WITH CIRCUMFLEX
     E7 |  000000E7 | LATIN SMALL LETTER C WITH CEDILLA
     E8 |  000000E8 | LATIN SMALL LETTER E WITH GRAVE
     E9 |  000000E9 | LATIN SMALL LETTER E WITH ACUTE
@@ -1100,27 +1087,26 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
     EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
     EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
-    F0 |  0000011F | LATIN SMALL LETTER G WITH BREVE
     F1 |  000000F1 | LATIN SMALL LETTER N WITH TILDE
     F2 |  000000F2 | LATIN SMALL LETTER O WITH GRAVE
     F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
     F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
-    F5 |  000000F5 | LATIN SMALL LETTER O WITH TILDE
+    F5 |  00000121 | LATIN SMALL LETTER G WITH DOT ABOVE
     F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
     F7 |  000000F7 | DIVISION SIGN
-    F8 |  000000F8 | LATIN SMALL LETTER O WITH STROKE
+    F8 |  0000011D | LATIN SMALL LETTER G WITH CIRCUMFLEX
     F9 |  000000F9 | LATIN SMALL LETTER U WITH GRAVE
     FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
     FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
     FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
-    FD |  00000131 | LATIN SMALL LETTER DOTLESS I
-    FE |  0000015F | LATIN SMALL LETTER S WITH CEDILLA
-    FF |  000000FF | LATIN SMALL LETTER Y WITH DIAERESIS
+    FD |  0000016D | LATIN SMALL LETTER U WITH BREVE
+    FE |  0000015D | LATIN SMALL LETTER S WITH CIRCUMFLEX
+    FF |  000002D9 | DOT ABOVE (Mandarin Chinese light tone)
 
 
 =head1 AUTHOR
 
-Copyright (C) 2002-2017 L<Guido Flohr|http://www.guido-flohr.net/>
+Copyright (C) 2002-2026 L<Guido Flohr|http://www.guido-flohr.net/>
 (L<mailto:guido.flohr@cantanea.com>), all rights reserved.  See the source
 code for details!code for details!
 
